Azure Application Insights client using asyncio and aiohttp
----------------------------------------------------------------
`Azure Application Insights <https://azure.microsoft.com/en-us/services/application-insights/>`_ Python SDK using asyncio, including a middleware for *aiohttp* web framework.

Why
````````````````````````````````````````````````````````````````
The official `Python SDK for Application Insights <https://github.com/Microsoft/ApplicationInsights-Python>`_ from Microsoft is designed to work with both 2.x and 3.x versions of Python language.

This repository contains an alternative Python SDK for Application Insights with support for ``asyncio`` and ``async/await`` syntax, targeting Python >=3.6 and also taking advantage of support for type hinting, available since recent versions of Python language.

To install:
    >>> pip install asynapplicationinsights

Repository
----------------------------------------------------------------
GitHub: https://github.com/RobertoPrevato/asynapplicationinsights

Documentation
----------------------------------------------------------------
Wiki: https://github.com/RobertoPrevato/asynapplicationinsights/wiki

